@@ -20,11 +20,11 @@ from __future__ import annotations
 from collections.abc import Sequence
 from typing import TYPE_CHECKING
 
+from airflow.providers.common.compat.sdk import BaseOperator
 from airflow.providers.segment.hooks.segment import SegmentHook
-from airflow.providers.segment.version_compat import BaseOperator
 
 if TYPE_CHECKING:
-    from airflow.providers.segment.version_compat import Context
+    from airflow.providers.common.compat.sdk import Context
 
 
 class SegmentTrackEventOperator(BaseOperator):
